summaryrefslogtreecommitdiff
path: root/fml/lib
diff options
context:
space:
mode:
authorfukachan <fukachan>2002-12-15 13:46:28 +0000
committerfukachan <fukachan>2002-12-15 13:46:28 +0000
commitd1fe458edcc5c321527e077395ce9177177dc3a4 (patch)
treee2f7de2b53f21436ae21e95defff3e66c0bf0b66 /fml/lib
parent569abb9b4cd23babba38904452a1ebdf30730e9b (diff)
downloadfml8-d1fe458edcc5c321527e077395ce9177177dc3a4.tar.gz
fml8-d1fe458edcc5c321527e077395ce9177177dc3a4.tar.bz2
fml8-d1fe458edcc5c321527e077395ce9177177dc3a4.zip
clean up comments
Diffstat (limited to 'fml/lib')
-rw-r--r--fml/lib/FML/Command/Admin/addadmin.pm4
-rw-r--r--fml/lib/FML/Command/Admin/adduser.pm4
-rw-r--r--fml/lib/FML/Command/Admin/bye.pm4
-rw-r--r--fml/lib/FML/Command/Admin/check.pm24
-rw-r--r--fml/lib/FML/Command/Admin/deladmin.pm8
-rw-r--r--fml/lib/FML/Command/Admin/delmoderator.pm6
-rw-r--r--fml/lib/FML/Command/Admin/deluser.pm4
-rw-r--r--fml/lib/FML/Command/Admin/digestoff.pm10
-rw-r--r--fml/lib/FML/Command/Admin/digeston.pm8
-rw-r--r--fml/lib/FML/Command/Admin/log.pm4
-rw-r--r--fml/lib/FML/Command/Admin/remove.pm4
-rw-r--r--fml/lib/FML/Command/Admin/signoff.pm4
-rw-r--r--fml/lib/FML/Command/Admin/unsubscribe.pm4
-rw-r--r--fml/lib/FML/Command/Admin/useradd.pm4
-rw-r--r--fml/lib/FML/Command/Admin/userdel.pm4
-rw-r--r--fml/lib/FML/Command/User/add.pm6
-rw-r--r--fml/lib/FML/Command/User/bye.pm6
-rw-r--r--fml/lib/FML/Command/User/deny.pm4
-rw-r--r--fml/lib/FML/Command/User/guide.pm4
-rw-r--r--fml/lib/FML/Command/User/help.pm4
-rw-r--r--fml/lib/FML/Command/User/info.pm4
-rw-r--r--fml/lib/FML/Command/User/mget.pm7
-rw-r--r--fml/lib/FML/Command/User/objective.pm6
-rw-r--r--fml/lib/FML/Command/User/remove.pm6
-rw-r--r--fml/lib/FML/Command/User/resign.pm6
-rw-r--r--fml/lib/FML/Command/User/signoff.pm4
-rw-r--r--fml/lib/FML/Command/User/summary.pm6
27 files changed, 86 insertions, 73 deletions
diff --git a/fml/lib/FML/Command/Admin/addadmin.pm b/fml/lib/FML/Command/Admin/addadmin.pm
index 238fdfaa..18d94d4d 100644
--- a/fml/lib/FML/Command/Admin/addadmin.pm
+++ b/fml/lib/FML/Command/Admin/addadmin.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: addadmin.pm,v 1.6 2002/09/11 23:18:06 fukachan Exp $
+# $FML: addadmin.pm,v 1.7 2002/09/22 14:56:43 fukachan Exp $
#
package FML::Command::Admin::addadmin;
@@ -23,7 +23,7 @@ See C<FML::Command> for more details.
=head1 DESCRIPTION
-add a new administrator address.
+add a new administrator mail address.
=head1 METHODS
diff --git a/fml/lib/FML/Command/Admin/adduser.pm b/fml/lib/FML/Command/Admin/adduser.pm
index 633f32d1..582e2a11 100644
--- a/fml/lib/FML/Command/Admin/adduser.pm
+++ b/fml/lib/FML/Command/Admin/adduser.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: adduser.pm,v 1.2 2002/09/11 23:18:06 fukachan Exp $
+# $FML: adduser.pm,v 1.3 2002/09/22 14:56:44 fukachan Exp $
#
package FML::Command::Admin::adduser;
@@ -17,7 +17,7 @@ use FML::Command::Admin::subscribe;
@ISA = qw(FML::Command::Admin::subscribe);
-# Descriptions: subscribe user
+# Descriptions: add a new member.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to subscribe module
# Return Value: none
diff --git a/fml/lib/FML/Command/Admin/bye.pm b/fml/lib/FML/Command/Admin/bye.pm
index eebf9e03..aa03ec82 100644
--- a/fml/lib/FML/Command/Admin/bye.pm
+++ b/fml/lib/FML/Command/Admin/bye.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: bye.pm,v 1.8 2002/09/11 23:18:06 fukachan Exp $
+# $FML: bye.pm,v 1.9 2002/09/22 14:56:44 fukachan Exp $
#
package FML::Command::Admin::bye;
@@ -17,7 +17,7 @@ use FML::Command::Admin::unsubscribe;
@ISA = qw(FML::Command::Admin::unsubscribe);
-# Descriptions: unsubscribe user
+# Descriptions: remove the specified user.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to unsubscribe module
# Return Value: none
diff --git a/fml/lib/FML/Command/Admin/check.pm b/fml/lib/FML/Command/Admin/check.pm
index 20a13ece..5218dcaa 100644
--- a/fml/lib/FML/Command/Admin/check.pm
+++ b/fml/lib/FML/Command/Admin/check.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: check.pm,v 1.4 2002/09/22 14:56:44 fukachan Exp $
+# $FML: check.pm,v 1.5 2002/09/24 14:23:12 fukachan Exp $
#
package FML::Command::Admin::check;
@@ -16,7 +16,7 @@ use FML::Log qw(Log LogWarn LogError);
=head1 NAME
-FML::Command::Admin::check - checknostic
+FML::Command::Admin::check - cheap diagnostic check.
=head1 SYNOPSIS
@@ -24,7 +24,7 @@ See C<FML::Command> for more detaicheck.
=head1 DESCRIPTION
-show user check(s).
+cheap diagnostic check.
=cut
@@ -63,6 +63,8 @@ sub process
my ($self, $curproc, $command_args) = @_;
my $config = $curproc->{ config };
+ # XXX-TODO validate $ml_name existence firstly.
+
for my $rule (@rules) {
$self->$rule($curproc, $command_args);
}
@@ -131,56 +133,56 @@ sub _dir_mode
}
-# Descriptions: check $dir mode is 0700
+# Descriptions: check if $dir mode is 0700
# Arguments: STR($dir)
# Side Effects: none
# Return Value: NUM(1 or 0)
sub _is_700
{
my ($dir) = @_;
- my $mode = _dir_mode($dir);
+ my $mode = _dir_mode($dir);
my $smode = sprintf("%o", $mode);
return ($smode eq '700' ? 1 : 0);
}
-# Descriptions: check $dir mode is 0770
+# Descriptions: check if $dir mode is 0770
# Arguments: STR($dir)
# Side Effects: none
# Return Value: NUM(1 or 0)
sub _is_770
{
my ($dir) = @_;
- my $mode = _dir_mode($dir);
+ my $mode = _dir_mode($dir);
my $smode = sprintf("%o", $mode);
return ($smode eq '770' ? 1 : 0);
}
-# Descriptions: check $dir mode is 0777
+# Descriptions: check if $dir mode is 0777
# Arguments: STR($dir)
# Side Effects: none
# Return Value: NUM(1 or 0)
sub _is_777
{
my ($dir) = @_;
- my $mode = _dir_mode($dir);
+ my $mode = _dir_mode($dir);
my $smode = sprintf("%o", $mode);
return ($smode eq '777' ? 1 : 0);
}
-# Descriptions: check $dir mode is 0755
+# Descriptions: check if $dir mode is 0755
# Arguments: STR($dir)
# Side Effects: none
# Return Value: NUM(1 or 0)
sub _is_755
{
my ($dir) = @_;
- my $mode = _dir_mode($dir);
+ my $mode = _dir_mode($dir);
my $smode = sprintf("%o", $mode);
return ($smode eq '755' ? 1 : 0);
diff --git a/fml/lib/FML/Command/Admin/deladmin.pm b/fml/lib/FML/Command/Admin/deladmin.pm
index 5254c4fc..39d67e75 100644
--- a/fml/lib/FML/Command/Admin/deladmin.pm
+++ b/fml/lib/FML/Command/Admin/deladmin.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: deladmin.pm,v 1.3 2002/09/11 23:18:07 fukachan Exp $
+# $FML: deladmin.pm,v 1.4 2002/09/22 14:56:44 fukachan Exp $
#
package FML::Command::Admin::deladmin;
@@ -23,7 +23,7 @@ See C<FML::Command> for more details.
=head1 DESCRIPTION
-deladmin a new user.
+remove the specified administrator.
=head1 METHODS
@@ -60,6 +60,10 @@ sub process
{
my ($self, $curproc, $command_args) = @_;
my $config = $curproc->{ config };
+
+ #
+ # XXX-TODO: remove targets are a set of admin_*_maps
+ #
my $member_map = $config->{ primary_admin_member_map };
my $recipient_map = $config->{ primary_admin_recipient_map };
my $options = $command_args->{ options };
diff --git a/fml/lib/FML/Command/Admin/delmoderator.pm b/fml/lib/FML/Command/Admin/delmoderator.pm
index 0c09ce6e..ae268c2e 100644
--- a/fml/lib/FML/Command/Admin/delmoderator.pm
+++ b/fml/lib/FML/Command/Admin/delmoderator.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: delmoderator.pm,v 1.2 2002/09/11 23:18:07 fukachan Exp $
+# $FML: delmoderator.pm,v 1.3 2002/09/22 14:56:44 fukachan Exp $
#
package FML::Command::Admin::delmoderator;
@@ -60,6 +60,10 @@ sub process
{
my ($self, $curproc, $command_args) = @_;
my $config = $curproc->{ config };
+
+ #
+ # XXX-TODO: targets are a set of moderator_*_maps
+ #
my $member_map = $config->{ primary_moderator_member_map };
my $recipient_map = $config->{ primary_moderator_recipient_map };
my $options = $command_args->{ options };
diff --git a/fml/lib/FML/Command/Admin/deluser.pm b/fml/lib/FML/Command/Admin/deluser.pm
index a464dabc..0a4798ef 100644
--- a/fml/lib/FML/Command/Admin/deluser.pm
+++ b/fml/lib/FML/Command/Admin/deluser.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: deluser.pm,v 1.2 2002/09/11 23:18:07 fukachan Exp $
+# $FML: deluser.pm,v 1.3 2002/09/22 14:56:44 fukachan Exp $
#
package FML::Command::Admin::deluser;
@@ -17,7 +17,7 @@ use FML::Command::Admin::unsubscribe;
@ISA = qw(FML::Command::Admin::unsubscribe);
-# Descriptions: unsubscribe user
+# Descriptions: remove the specified user.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to unsubscribe module
# Return Value: none
diff --git a/fml/lib/FML/Command/Admin/digeston.pm b/fml/lib/FML/Command/Admin/digeston.pm
index 123ff59b..12bf5af4 100644
--- a/fml/lib/FML/Command/Admin/digeston.pm
+++ b/fml/lib/FML/Command/Admin/digeston.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: digest.pm,v 1.2 2002/11/23 13:12:47 fukachan Exp $
+# $FML: digeston.pm,v 1.1 2002/11/24 02:52:43 fukachan Exp $
#
package FML::Command::Admin::digeston;
@@ -23,7 +23,7 @@ See C<FML::Command> for more details.
=head1 DESCRIPTION
-change digest mode for the specified address to off/on.
+enable digest mode for the specified address.
=head1 METHODS
@@ -52,7 +52,7 @@ sub new
sub need_lock { 1;}
-# Descriptions: change on or off digest mode
+# Descriptions: digest mode off/on for the specified user.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: update $recipient_map,$digest_recipient_maps
sub process
@@ -70,7 +70,7 @@ sub process
}
-# Descriptions: show cgi menu for on
+# Descriptions: show cgi menu for digeston
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: update $recipient_map
# Return Value: none
diff --git a/fml/lib/FML/Command/Admin/log.pm b/fml/lib/FML/Command/Admin/log.pm
index ccf4fd82..2835c53e 100644
--- a/fml/lib/FML/Command/Admin/log.pm
+++ b/fml/lib/FML/Command/Admin/log.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: log.pm,v 1.8 2002/09/11 23:18:07 fukachan Exp $
+# $FML: log.pm,v 1.9 2002/09/22 14:56:45 fukachan Exp $
#
package FML::Command::Admin::log;
@@ -52,7 +52,7 @@ sub new
sub need_lock { 0;}
-# Descriptions: show log files
+# Descriptions: show log file.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: update $member_map $recipient_map
# Return Value: none
diff --git a/fml/lib/FML/Command/Admin/remove.pm b/fml/lib/FML/Command/Admin/remove.pm
index be5a3258..fe0e958b 100644
--- a/fml/lib/FML/Command/Admin/remove.pm
+++ b/fml/lib/FML/Command/Admin/remove.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: remove.pm,v 1.8 2002/09/11 23:18:08 fukachan Exp $
+# $FML: remove.pm,v 1.9 2002/09/22 14:56:46 fukachan Exp $
#
package FML::Command::Admin::remove;
@@ -17,7 +17,7 @@ use FML::Command::Admin::unsubscribe;
@ISA = qw(FML::Command::Admin::unsubscribe);
-# Descriptions: unsubscribe user
+# Descriptions: remove the specified member.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to unsubscribe module
# Return Value: none
diff --git a/fml/lib/FML/Command/Admin/signoff.pm b/fml/lib/FML/Command/Admin/signoff.pm
index 8312bb84..4f49dbcf 100644
--- a/fml/lib/FML/Command/Admin/signoff.pm
+++ b/fml/lib/FML/Command/Admin/signoff.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: signoff.pm,v 1.8 2002/09/11 23:18:08 fukachan Exp $
+# $FML: signoff.pm,v 1.9 2002/09/22 14:56:46 fukachan Exp $
#
package FML::Command::Admin::signoff;
@@ -17,7 +17,7 @@ use FML::Command::Admin::unsubscribe;
@ISA = qw(FML::Command::Admin::unsubscribe);
-# Descriptions: unsubscribe user
+# Descriptions: remove the specified user.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to unsubscribe module
# Return Value: none
diff --git a/fml/lib/FML/Command/Admin/unsubscribe.pm b/fml/lib/FML/Command/Admin/unsubscribe.pm
index 35967f68..b4c4cd10 100644
--- a/fml/lib/FML/Command/Admin/unsubscribe.pm
+++ b/fml/lib/FML/Command/Admin/unsubscribe.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: unsubscribe.pm,v 1.15 2002/09/11 23:18:09 fukachan Exp $
+# $FML: unsubscribe.pm,v 1.16 2002/09/22 14:56:46 fukachan Exp $
#
package FML::Command::Admin::unsubscribe;
@@ -23,7 +23,7 @@ See C<FML::Command> for more details.
=head1 DESCRIPTION
-unsubscribe a new user.
+remove the specified user.
=head1 METHODS
diff --git a/fml/lib/FML/Command/Admin/useradd.pm b/fml/lib/FML/Command/Admin/useradd.pm
index 7d3fe2c0..c6f7c58a 100644
--- a/fml/lib/FML/Command/Admin/useradd.pm
+++ b/fml/lib/FML/Command/Admin/useradd.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: useradd.pm,v 1.2 2002/09/11 23:18:09 fukachan Exp $
+# $FML: useradd.pm,v 1.3 2002/09/22 14:56:46 fukachan Exp $
#
package FML::Command::Admin::useradd;
@@ -17,7 +17,7 @@ use FML::Command::Admin::subscribe;
@ISA = qw(FML::Command::Admin::subscribe);
-# Descriptions: subscribe user
+# Descriptions: add a new user.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to subscribe module
# Return Value: none
diff --git a/fml/lib/FML/Command/Admin/userdel.pm b/fml/lib/FML/Command/Admin/userdel.pm
index 4d95db81..90394655 100644
--- a/fml/lib/FML/Command/Admin/userdel.pm
+++ b/fml/lib/FML/Command/Admin/userdel.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: userdel.pm,v 1.2 2002/09/11 23:18:09 fukachan Exp $
+# $FML: userdel.pm,v 1.3 2002/09/22 14:56:46 fukachan Exp $
#
package FML::Command::Admin::userdel;
@@ -17,7 +17,7 @@ use FML::Command::Admin::unsubscribe;
@ISA = qw(FML::Command::Admin::unsubscribe);
-# Descriptions: unsubscribe user
+# Descriptions: remove the specified user.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to unsubscribe module
# Return Value: none
diff --git a/fml/lib/FML/Command/User/add.pm b/fml/lib/FML/Command/User/add.pm
index 6a14547d..d46fadcb 100644
--- a/fml/lib/FML/Command/User/add.pm
+++ b/fml/lib/FML/Command/User/add.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: add.pm,v 1.8 2002/09/11 23:18:09 fukachan Exp $
+# $FML: add.pm,v 1.9 2002/09/22 14:56:47 fukachan Exp $
#
package FML::Command::User::add;
@@ -17,7 +17,7 @@ use FML::Command::User::subscribe;
@ISA = qw(FML::Command::User::subscribe);
-# Descriptions: subscribe user
+# Descriptions: subscribe request, which forwarded to subscribe module.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to subscribe module
# Return Value: none
@@ -30,7 +30,7 @@ sub process
=head1 NAME
-FML::Command::User::add - add a new member
+FML::Command::User::add - subscribe request command
=head1 SYNOPSIS
diff --git a/fml/lib/FML/Command/User/bye.pm b/fml/lib/FML/Command/User/bye.pm
index 407d46dc..5c24186d 100644
--- a/fml/lib/FML/Command/User/bye.pm
+++ b/fml/lib/FML/Command/User/bye.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: bye.pm,v 1.9 2002/09/11 23:18:09 fukachan Exp $
+# $FML: bye.pm,v 1.10 2002/09/22 14:56:47 fukachan Exp $
#
package FML::Command::User::bye;
@@ -17,7 +17,7 @@ use FML::Command::User::unsubscribe;
@ISA = qw(FML::Command::User::unsubscribe);
-# Descriptions: unsubscribe user
+# Descriptions: unsubscribe request, forwarded to "unsubscribe" module.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to unsubscribe module
# Return Value: none
@@ -30,7 +30,7 @@ sub process
=head1 NAME
-FML::Command::User::bye - remove the specified member
+FML::Command::User::bye - unsubscribe request command
=head1 SYNOPSIS
diff --git a/fml/lib/FML/Command/User/deny.pm b/fml/lib/FML/Command/User/deny.pm
index 39c4ed92..fafd34b2 100644
--- a/fml/lib/FML/Command/User/deny.pm
+++ b/fml/lib/FML/Command/User/deny.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: deny.pm,v 1.5 2002/09/11 23:18:09 fukachan Exp $
+# $FML: deny.pm,v 1.6 2002/09/22 14:56:47 fukachan Exp $
#
package FML::Command::User::deny;
@@ -55,7 +55,7 @@ sub new
sub need_lock { 1;}
-# Descriptions: send file by FML::Command::SendFile.
+# Descriptions: send deny file by FML::Command::SendFile.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: none
# Return Value: none
diff --git a/fml/lib/FML/Command/User/guide.pm b/fml/lib/FML/Command/User/guide.pm
index 86a9733e..accaeb25 100644
--- a/fml/lib/FML/Command/User/guide.pm
+++ b/fml/lib/FML/Command/User/guide.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: guide.pm,v 1.9 2002/09/11 23:18:10 fukachan Exp $
+# $FML: guide.pm,v 1.10 2002/09/22 14:56:47 fukachan Exp $
#
package FML::Command::User::guide;
@@ -56,7 +56,7 @@ sub new
sub need_lock { 1;}
-# Descriptions: send file by FML::Command::SendFile.
+# Descriptions: send guide file by FML::Command::SendFile.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: none
# Return Value: none
diff --git a/fml/lib/FML/Command/User/help.pm b/fml/lib/FML/Command/User/help.pm
index 9a60760c..32799f6c 100644
--- a/fml/lib/FML/Command/User/help.pm
+++ b/fml/lib/FML/Command/User/help.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: help.pm,v 1.13 2002/09/11 23:18:10 fukachan Exp $
+# $FML: help.pm,v 1.14 2002/09/22 14:56:47 fukachan Exp $
#
package FML::Command::User::help;
@@ -56,7 +56,7 @@ sub new
sub need_lock { 1;}
-# Descriptions: send file by FML::Command::SendFile.
+# Descriptions: send help file by FML::Command::SendFile.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: none
# Return Value: none
diff --git a/fml/lib/FML/Command/User/info.pm b/fml/lib/FML/Command/User/info.pm
index 160c2e42..1cf44bd1 100644
--- a/fml/lib/FML/Command/User/info.pm
+++ b/fml/lib/FML/Command/User/info.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: info.pm,v 1.6 2002/09/11 23:18:10 fukachan Exp $
+# $FML: info.pm,v 1.7 2002/09/22 14:56:47 fukachan Exp $
#
package FML::Command::User::info;
@@ -38,6 +38,8 @@ See C<FML::Command> for more details.
=head1 DESCRIPTION
+an alias of "guide" module.
+
=head1 CODING STYLE
See C<http://www.fml.org/software/FNF/> on fml coding style guide.
diff --git a/fml/lib/FML/Command/User/mget.pm b/fml/lib/FML/Command/User/mget.pm
index 844f5b5d..44101aec 100644
--- a/fml/lib/FML/Command/User/mget.pm
+++ b/fml/lib/FML/Command/User/mget.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: mget.pm,v 1.10 2002/09/11 23:18:10 fukachan Exp $
+# $FML: mget.pm,v 1.11 2002/09/22 14:56:47 fukachan Exp $
#
package FML::Command::User::mget;
@@ -16,7 +16,8 @@ use FML::Command::User::get;
@ISA = qw(FML::Command::User::get);
-# Descriptions: send article(s)
+# Descriptions: send back article(s).
+# The request is forwarded to "get" module.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to get module
# Return Value: none
@@ -29,7 +30,7 @@ sub process
=head1 NAME
-FML::Command::User::mget - send articles
+FML::Command::User::mget - send back article(s)
=head1 SYNOPSIS
diff --git a/fml/lib/FML/Command/User/objective.pm b/fml/lib/FML/Command/User/objective.pm
index 652aefb4..c1b2f86b 100644
--- a/fml/lib/FML/Command/User/objective.pm
+++ b/fml/lib/FML/Command/User/objective.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: objective.pm,v 1.5 2002/09/11 23:18:10 fukachan Exp $
+# $FML: objective.pm,v 1.6 2002/09/22 14:56:47 fukachan Exp $
#
package FML::Command::User::objective;
@@ -18,7 +18,7 @@ use FML::Log qw(Log LogWarn LogError);
=head1 NAME
-FML::Command::User::objective - send back objective file
+FML::Command::User::objective - send back ML's objective file
=head1 SYNOPSIS
@@ -55,7 +55,7 @@ sub new
sub need_lock { 1;}
-# Descriptions: send file by FML::Command::SendFile.
+# Descriptions: send back objective file by FML::Command::SendFile.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: none
# Return Value: none
diff --git a/fml/lib/FML/Command/User/remove.pm b/fml/lib/FML/Command/User/remove.pm
index dbd1d7c7..ccd14ae5 100644
--- a/fml/lib/FML/Command/User/remove.pm
+++ b/fml/lib/FML/Command/User/remove.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: remove.pm,v 1.9 2002/09/11 23:18:10 fukachan Exp $
+# $FML: remove.pm,v 1.10 2002/09/22 14:56:48 fukachan Exp $
#
package FML::Command::User::remove;
@@ -17,7 +17,7 @@ use FML::Command::User::unsubscribe;
@ISA = qw(FML::Command::User::unsubscribe);
-# Descriptions: unsubscribe user
+# Descriptions: unsubscribe request, forwarded to "unsubscribe" module.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to unsubscribe module
# Return Value: none
@@ -30,7 +30,7 @@ sub process
=head1 NAME
-FML::Command::User::remove - unsubscribe
+FML::Command::User::remove - unsubscribe request command
=head1 SYNOPSIS
diff --git a/fml/lib/FML/Command/User/resign.pm b/fml/lib/FML/Command/User/resign.pm
index 11a02e23..09321aea 100644
--- a/fml/lib/FML/Command/User/resign.pm
+++ b/fml/lib/FML/Command/User/resign.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: resign.pm,v 1.9 2002/09/11 23:18:10 fukachan Exp $
+# $FML: resign.pm,v 1.10 2002/09/22 14:56:48 fukachan Exp $
#
package FML::Command::User::resign;
@@ -17,7 +17,7 @@ use FML::Command::User::unsubscribe;
@ISA = qw(FML::Command::User::unsubscribe);
-# Descriptions: unsubscribe user
+# Descriptions: unsubscribe request, forwarded to "unsubscribe" module.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to unsubscribe module
# Return Value: none
@@ -29,7 +29,7 @@ sub process
=head1 NAME
-FML::Command::User::resign - unsubscribe
+FML::Command::User::resign - unsubscribe request command
=head1 SYNOPSIS
diff --git a/fml/lib/FML/Command/User/signoff.pm b/fml/lib/FML/Command/User/signoff.pm
index 09d8de25..dba37bad 100644
--- a/fml/lib/FML/Command/User/signoff.pm
+++ b/fml/lib/FML/Command/User/signoff.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: signoff.pm,v 1.10 2002/09/11 23:18:10 fukachan Exp $
+# $FML: signoff.pm,v 1.11 2002/09/22 14:56:48 fukachan Exp $
#
package FML::Command::User::signoff;
@@ -17,7 +17,7 @@ use FML::Command::User::unsubscribe;
@ISA = qw(FML::Command::User::unsubscribe use);
-# Descriptions: unsubscribe user
+# Descriptions: unsubscribe request, forwarded to "unsubscribe" command.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to unsubscribe module
# Return Value: none
diff --git a/fml/lib/FML/Command/User/summary.pm b/fml/lib/FML/Command/User/summary.pm
index c7395580..6313e8d7 100644
--- a/fml/lib/FML/Command/User/summary.pm
+++ b/fml/lib/FML/Command/User/summary.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: summary.pm,v 1.10 2002/09/11 23:18:10 fukachan Exp $
+# $FML: summary.pm,v 1.11 2002/09/22 14:56:48 fukachan Exp $
#
package FML::Command::User::summary;
@@ -19,7 +19,7 @@ use FML::Log qw(Log LogWarn LogError);
=head1 NAME
-FML::Command::User::summary - send back summary file
+FML::Command::User::summary - send back ML's summary file
=head1 SYNOPSIS
@@ -56,7 +56,7 @@ sub new
sub need_lock { 1;}
-# Descriptions: send file by FML::Command::SendFile.
+# Descriptions: send summary file by FML::Command::SendFile.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: none
# Return Value: none
diff --git a/fml/lib/FML/Command/Admin/digestoff.pm b/fml/lib/FML/Command/Admin/digestoff.pm
index 0d9355d6..96ae1a29 100644
--- a/fml/lib/FML/Command/Admin/digestoff.pm
+++ b/fml/lib/FML/Command/Admin/digestoff.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: digest.pm,v 1.2 2002/11/23 13:12:47 fukachan Exp $
+# $FML: digestoff.pm,v 1.1 2002/11/24 02:52:43 fukachan Exp $
#
package FML::Command::Admin::digestoff;
@@ -15,7 +15,7 @@ use vars qw(@ISA @EXPORT @EXPORT_OK $AUTOLOAD);
=head1 NAME
-FML::Command::Admin::digest - digest mode on
+FML::Command::Admin::digest - digest mode off
=head1 SYNOPSIS
@@ -23,7 +23,7 @@ See C<FML::Command> for more details.
=head1 DESCRIPTION
-change digest mode for the specified address to off/on.
+disable digest mode for the specified address.
=head1 METHODS
@@ -52,7 +52,7 @@ sub new
sub need_lock { 1;}
# Descriptions: change on or off digest mode
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: update $recipient_map,$digest_recipient_maps
sub process
@@ -70,7 +70,7 @@ sub process
}
-# Descriptions: show cgi menu for on
+# Descriptions: show cgi menu for digestoff.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: update $recipient_map
# Return Value: none
@@ -52,7 +52,7 @@ sub new
sub need_lock { 1;}
-# Descriptions: change on or off digest mode
+# Descriptions: disable digest mode for the specified user.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: update $recipient_map,$digest_recipient_maps